==> ferret-vis_6.9.3.orig.tar.xz: ferret-vis-6.9.3/fer/ccr/xfer_c_ptrs.c <==
/*
*
*  This software was developed by the Thermal Modeling and Analysis
*  Project(TMAP) of the National Oceanographic and Atmospheric
*  Administration's (NOAA) Pacific Marine Environmental Lab(PMEL),
*  hereafter referred to as NOAA/PMEL/TMAP.
*
*  Access and use of this software shall impose the following
*  obligations and understandings on the user. The user is granted the
*  right, without any fee or cost, to use, copy, modify, alter, enhance
*  and distribute this software, and any derivative works thereof, and
*  its supporting documentation for any purpose whatsoever, provided
*  that this entire notice appears in all copies of the software,
*  derivative works and supporting documentation.  Further, the user
*  agrees to credit NOAA/PMEL/TMAP in any publications that result from
*  the use of this software or in any product that includes this
*  software. The names TMAP, NOAA and/or PMEL, however, may not be used
*  in any advertising or publicity to endorse or promote any products
*  or commercial entity unless specific written permission is obtained
*  from NOAA/PMEL/TMAP. The user also understands that NOAA/PMEL/TMAP
*  is not obligated to provide the user with any support, consulting,
*  training or assistance of any kind with regard to the use, operation
*  and performance of this software nor to provide the user with any
*  updates, revisions, new versions or "bug fixes".
*
*  THIS SOFTWARE IS PROVIDED BY NOAA/PMEL/TMAP "AS IS" AND ANY EXPRESS
*  OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
*  WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
*  ARE DISCLAIMED. IN NO EVENT SHALL NOAA/PMEL/TMAP BE LIABLE FOR ANY SPECIAL,
*  INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER
*  RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF
*  CONTRACT, NEGLIGENCE OR OTHER TORTUOUS ACTION, ARISING OUT OF OR IN
*  CONNECTION WITH THE ACCESS, USE OR PERFORMANCE OF THIS SOFTWARE.  
*/


/* 
 *  Copy pointer values from the source array of pointers to the destination
 *  Pointer may be spaced "naturally" (_del=0) or at 8 byte intervals (_del=1).
 */

#include <stdlib.h>

void xfer_c_ptrs_(src_ptr, src_del, src_offset,
		  dst_ptr, dst_del, dst_offset, nptr)
     char*** src_ptr;
     int* src_del;
     int* src_offset;
     char*** dst_ptr;
     int* dst_del;
     int* dst_offset;
     int* nptr;
{
   int src_delta = *src_del ? 8/sizeof(char**) : 1;
   int dst_delta = *dst_del ? 8/sizeof(char**) : 1;
   char** src = *src_ptr + (*src_offset * src_delta) ;
   char** dst = *dst_ptr + (*dst_offset * dst_delta) ;
   int i;

   for (i=0; i<*nptr; i++) {
      if ( *dst != NULL )
         free(*dst);
      *dst = *src;
      src += src_delta;
      dst += dst_delta;
   }
}

==> ferret-vis_7.6.0.orig.tar.xz: ferret-vis-7.6.0/fer/ccr/xfer_c_ptrs.c <==
/*
*
*  This software was developed by the Thermal Modeling and Analysis
*  Project(TMAP) of the National Oceanographic and Atmospheric
*  Administration's (NOAA) Pacific Marine Environmental Lab(PMEL),
*  hereafter referred to as NOAA/PMEL/TMAP.
*
*  Access and use of this software shall impose the following
*  obligations and understandings on the user. The user is granted the
*  right, without any fee or cost, to use, copy, modify, alter, enhance
*  and distribute this software, and any derivative works thereof, and
*  its supporting documentation for any purpose whatsoever, provided
*  that this entire notice appears in all copies of the software,
*  derivative works and supporting documentation.  Further, the user
*  agrees to credit NOAA/PMEL/TMAP in any publications that result from
*  the use of this software or in any product that includes this
*  software. The names TMAP, NOAA and/or PMEL, however, may not be used
*  in any advertising or publicity to endorse or promote any products
*  or commercial entity unless specific written permission is obtained
*  from NOAA/PMEL/TMAP. The user also understands that NOAA/PMEL/TMAP
*  is not obligated to provide the user with any support, consulting,
*  training or assistance of any kind with regard to the use, operation
*  and performance of this software nor to provide the user with any
*  updates, revisions, new versions or "bug fixes".
*
*  THIS SOFTWARE IS PROVIDED BY NOAA/PMEL/TMAP "AS IS" AND ANY EXPRESS
*  OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
*  WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
*  ARE DISCLAIMED. IN NO EVENT SHALL NOAA/PMEL/TMAP BE LIABLE FOR ANY SPECIAL,
*  INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER
*  RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF
*  CONTRACT, NEGLIGENCE OR OTHER TORTUOUS ACTION, ARISING OUT OF OR IN
*  CONNECTION WITH THE ACCESS, USE OR PERFORMANCE OF THIS SOFTWARE.  
*/


/* 
 *  Copy pointer values from the source array of pointers to the destination
 *  Pointer may be spaced "naturally" (_del=0) or at 8 byte intervals (_del=1).
 */

#include <stdlib.h>
#include "ferret.h"
#include "FerMem.h"

void FORTRAN(xfer_c_ptrs)(char ***src_ptr, int *src_del, int *src_offset,
		          char ***dst_ptr, int *dst_del, int *dst_offset, int *nptr)
{
   int src_delta = *src_del ? 8/sizeof(char**) : 1;
   int dst_delta = *dst_del ? 8/sizeof(char**) : 1;
   char** src = *src_ptr + (*src_offset * src_delta) ;
   char** dst = *dst_ptr + (*dst_offset * dst_delta) ;
   int i;

   for (i=0; i<*nptr; i++) {
      if ( *dst != NULL )
         FerMem_Free(*dst, __FILE__, __LINE__);
      *dst = *src;
      src += src_delta;
      dst += dst_delta;
   }
}
